@@ -1,41 +1,61 @@
 use crate::profile::Profile;
 use crate::EntityError;
 use ockam_core::hex::encode;
-use ockam_core::Result;
+use ockam_core::lib::convert::TryFrom;
+use ockam_core::lib::fmt::Formatter;
+use ockam_core::lib::Display;
+use ockam_core::{Error, Result};
 use ockam_vault_core::{Hasher, KeyId};
 use serde::{Deserialize, Serialize};
 
 /// An identifier of a Profile.
 #[derive(Clone, Debug, Eq, PartialEq, Hash, Serialize, Deserialize, Default)]
-pub struct ProfileIdentifier(KeyId);
+pub struct EntityIdentifier(KeyId);
+
+pub type ProfileIdentifier = EntityIdentifier;
 
 /// Unique [`crate::Profile`] identifier, computed as SHA256 of root public key
-impl ProfileIdentifier {
-    /// Create a ProfileIdentifier from a KeyId
+impl EntityIdentifier {
+    /// Create a EntityIdentifier from a KeyId
     pub fn from_key_id(key_id: KeyId) -> Self {
         Self { 0: key_id }
     }
-    /// Human-readable form of the id
-    pub fn to_external(&self) -> String {
-        format!("P_ID.{}", &self.0)
-    }
-    pub fn from_external(str: &str) -> Result<Self> {
-        if let Some(str) = str.strip_prefix("P_ID.") {
-            Ok(Self::from(str))
-        } else {
-            Err(EntityError::InvalidProfileId.into())
-        }
-    }
-
     /// Return the wrapped KeyId
     pub fn key_id(&self) -> &KeyId {
         &self.0
     }
 }
 
-impl From<&str> for ProfileIdentifier {
-    fn from(s: &str) -> Self {
-        ProfileIdentifier::from_key_id(s.into())
+impl Display for EntityIdentifier {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        let str: String = self.clone().into();
+        write!(f, "{}", &str)
+    }
+}
+
+impl Into<String> for EntityIdentifier {
+    fn into(self) -> String {
+        format!("P{}", &self.0)
+    }
+}
+
+impl TryFrom<&str> for EntityIdentifier {
+    type Error = Error;
+
+    fn try_from(value: &str) -> Result<Self> {
+        if let Some(str) = value.strip_prefix("P") {
+            Ok(Self::from_key_id(str.into()))
+        } else {
+            Err(EntityError::InvalidProfileId.into())
+        }
+    }
+}
+
+impl TryFrom<String> for EntityIdentifier {
+    type Error = Error;
+
+    fn try_from(value: String) -> Result<Self> {
+        Self::try_from(value.as_str())
     }
 }
 
@@ -70,16 +90,28 @@ impl EventIdentifier {
 #[cfg(test)]
 mod test {
     use super::*;
+    use ockam_core::lib::convert::TryInto;
     use rand::{thread_rng, RngCore};
 
-    impl ProfileIdentifier {
-        pub fn random() -> ProfileIdentifier {
-            ProfileIdentifier(format!("{:x}", thread_rng().next_u64()))
+    impl EntityIdentifier {
+        pub fn random() -> EntityIdentifier {
+            EntityIdentifier(format!("{:x}", thread_rng().next_u64()))
         }
     }
 
     #[test]
     fn test_new() {
-        let _identifier = ProfileIdentifier::from_key_id("test".to_string());
+        let _identifier = EntityIdentifier::from_key_id("test".to_string());
+    }
+
+    #[test]
+    fn test_into() {
+        let id1 = EntityIdentifier::random();
+
+        let str: String = id1.clone().into();
+        assert!(str.starts_with("P"));
+
+        let id2: EntityIdentifier = str.try_into().unwrap();
+        assert_eq!(id1, id2);
     }
 }
