@@ -32,8 +32,8 @@ pub enum IdentityRequest {
     VerifyContact(Id, Contact),
     VerifyAndUpdateContact(Id, Id, Changes),
     RemoveProfile(Id),
-    CreateSecureChannelListener(Id, Address),
-    CreateSecureChannel(Id, Route),
+    CreateSecureChannelListener(Id, Address, Address),
+    CreateSecureChannel(Id, Route, Address),
     GetSigningKey(Id),
     GetIssuerPublicKey(Id),
     CreateOffer(Id, CredentialSchema),
